@@ -17,6 +17,7 @@ DOCKER_USERNAME = "dockerUsername"  # String
 ENV = "environment"  # Dictionary
 EXCLUSIVE_WORKERS = "exclusiveWorkers"  # Boolean
 EXECUTABLE = "executable"  # String
+FINISH_IF_ALL_TASKS_FINISHED = "finishIfAllTasksFinished"  # Boolean
 FINISH_IF_ANY_TASK_FAILED = "finishIfAnyTaskFailed"  # Boolean
 FLATTEN_PATHS = "flattenInputPaths"  # Boolean
 FLATTEN_UPLOAD_PATHS = "flattenUploadPaths"  # Boolean
@@ -31,6 +32,7 @@ MAX_RETRIES = "maximumTaskRetries"  # Integer
 MAX_WORKERS = "maxWorkers"  # Integer
 MIN_NODES = "minNodes"  # Integer
 MIN_WORKERS = "minWorkers"  # Integer
+MUSTACHE = "mustache"  # Dictionary
 NAME = "name"  # String
 NAMESPACE = "namespace"  # String
 NAME_TAG = "tag"  # String
@@ -52,6 +54,7 @@ URL = "url"  # String
 VCPUS = "vcpus"  # List of two Floats
 VERIFY_AT_START = "verifyAtStart"  # List of Strings
 VERIFY_WAIT = "verifyWait"  # List of Strings
+WORKERS_PER_VCPU = "workersPerVCPU"  # Integer
 WORKERS_PER_NODE = "workersPerNode"  # Integer
 WORKER_POOL_SECTION = "workerPool"  # String
 WORKER_TAG = "workerTag"  # String
@@ -67,7 +70,6 @@ BASH_SCRIPT = "bashScript"  # String
 
 ALL_KEYS = [
     ARGS,
-    FINISH_IF_ANY_TASK_FAILED,
     AUTO_SCALING_IDLE_DELAY,
     AUTO_SHUTDOWN,
     AUTO_SHUTDOWN_DELAY,
@@ -83,6 +85,8 @@ ALL_KEYS = [
     ENV,
     EXCLUSIVE_WORKERS,
     EXECUTABLE,
+    FINISH_IF_ALL_TASKS_FINISHED,
+    FINISH_IF_ANY_TASK_FAILED,
     FLATTEN_PATHS,
     FLATTEN_UPLOAD_PATHS,
     FULFIL_ON_SUBMIT,
@@ -96,6 +100,7 @@ ALL_KEYS = [
     MAX_WORKERS,
     MIN_NODES,
     MIN_WORKERS,
+    MUSTACHE,
     NAMESPACE,
     NAME_TAG,
     NODE_BOOT_TIME_LIMIT,
@@ -116,6 +121,7 @@ ALL_KEYS = [
     VCPUS,
     VERIFY_AT_START,
     VERIFY_WAIT,
+    WORKERS_PER_VCPU,
     WORKERS_PER_NODE,
     WORKER_POOL_SECTION,
     WORKER_TAG,
